/*
 *  Copyright 2015 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.blog');

/**
 * Listener
 */
org.ametys.blog.BlogPostListener = function()
{
	org.ametys.messagebus.MessageBus.getInstance().register(this);
}

org.ametys.blog.BlogPostListener.prototype.onMessage = function (messages)
{
	for (var i=0; i < messages.length; i++)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED || messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_DELETED || messages[i].getType().getName() == 'archived')
		{
			var targets = messages[i].getTargets();
			var postTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, this._checkTarget.createDelegate(this));
			
			if (postTarget != null)
			{
				var siteName = context.parameters.siteName;
				var lang = org.ametys.web.helper.LanguageHelper.getCurrentLanguage();
				var serverMessage = new org.ametys.servercomm.ServerMessage('blog', '/' + siteName + '/' + lang + '/blog-root-page.xml', {}, org.ametys.servercomm.ServerComm.PRIORITY_SYNCHRONOUS, null, this, null);
				var response = org.ametys.servercomm.ServerComm.getInstance().send(serverMessage);
				
				if (response != null || response.getAttribute("code") == "200")
				{
					var rootPage = response.selectSingleNode("blog-root-page");
					if (rootPage != null)
					{
						var target;
						var pageId = rootPage.getAttribute('id');
						if (pageId.indexOf("sitemap://") == 0)
					    {
					        target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget('sitemap', {'id': pageId});
					    }
					    else
					    {
					        target = org.ametys.messagebus.bus.MessageBuilder.getInstance().createTarget('page', {'id': pageId});
					    }
						
						var events = [];
						events.push(org.ametys.messagebus.bus.MessageBuilder.getInstance().createMessage('needReload', null, [target]));
						org.ametys.messagebus.MessageBus.getInstance().fireMessages(events);
					}
				}
			}
		}
	}
}

org.ametys.blog.BlogPostListener.prototype._checkTarget = function (target)
{
	return target.getType() == "content" && (target.getParameters().type == 'org.ametys.plugins.blog.Content.post');
}

// Create listener
new org.ametys.blog.BlogPostListener ();
